==> page-ide-1.0.2.tgz: package/lib/service/tool-service.js <==
/**
 *@author       叶章浩
 *@date         2019/1/15 15:16
 *@Copyright    天源迪科信息技术股份有限公司
 *@Description  事项接口
 */


export default class InstancesService  {

    //note

    //note 删除  deleteProcessList
    static async deleteProcessList(data) {
        // return ServiceRequest.post(`item/qryConfigFormItemList`, data)

        return ServiceRequest('itemFormJson/delItemFormBusiInfo',{
            mock:false,
            body:{
                data:data
            }
        });
    };

  //note 查询所有事项列表接口
  static async selectProcessList(data) {
   // return ServiceRequest.post(`item/qryConfigFormItemList`, data)

      return ServiceRequest('item/qryConfigFormItemList',{
          mock:false,
          body:{
              data:data
          }
      });
  };

    //note 查询本地表单 假数据的信息
    static async selectLocalFormProp(data) {
        // item/qryItemForm/qryItemFormTemp?itemNo=D199AA2F73FE4B4FA3678CFB2F7AC129
        let params = {

        };
       // return  this.$http.get('/lib/static/data/localForm.json');

           return ServiceRequest('/lib/static/data/localForm.json',{
            mock:true,
            body:{
                data:params
            }
        });
    };

   //note 查询当前表单的信息
    static async selectFormProp(data) {
        // item/qryItemForm/qryItemFormTemp?itemNo=D199AA2F73FE4B4FA3678CFB2F7AC129
        let params = {
            itemNo:localStorage.itemNo,
            itemStep:localStorage.itemStep,
            jsonType:2
        };
        return ServiceRequest('item/qryItemForm/qryItemFormTemp',{
            mock:false,
            body:{
                data:params
            }
        });
        // return ServiceRequest.post('getTemplateData', data, true);
    };

    //note 查询当前表单的信息
    static async saveJsonToServer(data) {
        // item/qryItemForm/qryItemFormTemp?itemNo=D199AA2F73FE4B4FA3678CFB2F7AC129

        return ServiceRequest('item/qryItemForm/qryItemFormTemp',{
            mock:false,
            body:{
                data:data
            }
        });
        // return ServiceRequest.post('getTemplateData', data, true);
    };
    //note 保存JSON或Template到后台
    static async saveTemplateOrJsonToServer(data) {
        // item/qryItemForm/qryItemFormTemp?itemNo=D199AA2F73FE4B4FA3678CFB2F7AC129

        return ServiceRequest('itemFormJson/saveItemFormJsonInfo',{
            mock:false,
            body:{
                data:data
            }
        });
        // return ServiceRequest.post('getTemplateData', data, true);
    };
    //note 加载存储的模板信息
    static async selectTemplateInfo(data) {
        // return ServiceRequest.post(`item/qryConfigFormItemList`, data)

        return ServiceRequest('itemFormJson/qryItemFormBusiInfo',{
            mock:false,
            body:{
                data:data
            }
        });
    };

    //note 加载存储的模板信息
    static async selectTemplateInfo(data) {
        // return ServiceRequest.post(`item/qryConfigFormItemList`, data)

        return ServiceRequest('itemFormJson/qryItemFormBusiInfo',{
            mock:false,
            body:{
                data:data
            }
        });
    };
    //note 查询公共配置JSON
    static async selectCommonConfigInfo(data) {
        // return ServiceRequest.post(`item/qryConfigFormItemList`, data)

        return ServiceRequest('/lib/static/data/common-config.json',{
            mock:false,
            body:{
                data:data
            }
        });
    };
}

==> page-ide-1.0.5.tgz: package/lib/service/tool-service.js <==
/**
 *@author       叶章浩
 *@date         2019/1/15 15:16
 *@Copyright    天源迪科信息技术股份有限公司
 *@Description  事项接口
 */


export default class InstancesService  {

    //note

    //note 删除  deleteProcessList
    static async deleteProcessList(data) {
        // return ServiceRequest.post(`item/qryConfigFormItemList`, data)

        return ServiceRequest('itemFormJson/delItemFormBusiInfo',{
            mock:false,
            body:{
                data:data
            }
        });
    };

  //note 查询所有事项列表接口
  static async selectProcessList(data) {
   // return ServiceRequest.post(`item/qryConfigFormItemList`, data)

      return ServiceRequest('item/qryConfigFormItemList',{
          mock:false,
          body:{
              data:data
          }
      });
  };

    //note 查询本地表单 假数据的信息
   //note 查询当前表单的信息
    static async selectFormProp(data) {
        // item/qryItemForm/qryItemFormTemp?itemNo=D199AA2F73FE4B4FA3678CFB2F7AC129
        localStorage.itemNo="D199AA2F73FE4B4FA3678CFB2F7AC129";
        localStorage.itemStep="1";
        let params = {
            itemNo:localStorage.itemNo,
            itemStep:localStorage.itemStep,
            jsonType:2
        };
        return ServiceRequest('item/qryItemForm/qryItemFormTemp',{
            mock:false,
            body:{
                data:params
            }
        });
        // return ServiceRequest.post('getTemplateData', data, true);
    };

    //note 查询当前表单的信息
    static async saveJsonToServer(data) {
        // item/qryItemForm/qryItemFormTemp?itemNo=D199AA2F73FE4B4FA3678CFB2F7AC129

        return ServiceRequest('item/qryItemForm/qryItemFormTemp',{
            mock:false,
            body:{
                data:data
            }
        });
        // return ServiceRequest.post('getTemplateData', data, true);
    };
    //note 保存JSON或Template到后台
    static async saveTemplateOrJsonToServer(data) {
        // item/qryItemForm/qryItemFormTemp?itemNo=D199AA2F73FE4B4FA3678CFB2F7AC129

        return ServiceRequest('itemFormJson/saveItemFormJsonInfo',{
            mock:false,
            body:{
                data:data
            }
        });
        // return ServiceRequest.post('getTemplateData', data, true);
    };
    //note 加载存储的模板信息
    static async selectTemplateInfo(data) {
        // return ServiceRequest.post(`item/qryConfigFormItemList`, data)

        return ServiceRequest('itemFormJson/qryItemFormBusiInfo',{
            mock:false,
            body:{
                data:data
            }
        });
    };

    //note 加载存储的模板信息
    static async selectTemplateInfo(data) {
        // return ServiceRequest.post(`item/qryConfigFormItemList`, data)

        return ServiceRequest('itemFormJson/qryItemFormBusiInfo',{
            mock:false,
            body:{
                data:data
            }
        });
    };
    //note 查询公共配置JSON
    static async selectCommonConfigInfo(data) {
        // return ServiceRequest.post(`item/qryConfigFormItemList`, data)

        return ServiceRequest('/static/data/page-ide/common-config.json',{
            mock:false,
            body:{
                data:data
            }
        });
    };
}
